==> php81-nextcloud-28.0.2.tgz: share/nextcloud/apps/user_status/l10n/zh_TW.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "最近的狀態",
    "No recent status changes" : "最近沒有狀態變更",
    "In a meeting" : "會議中",
    "Commuting" : "通勤中",
    "Out sick" : "生病",
    "Vacationing" : "休假",
    "Out of office" : "不在辦公室",
    "Working remotely" : "遠地工作",
    "In a call" : "通話中",
    "User status" : "使用者狀態",
    "Clear status after" : "清空狀態於……之後",
    "Emoji for your status message" : "狀態訊息的表情符號",
    "What is your status?" : "您目前的狀態是什麼呢？",
    "Predefined statuses" : "預先定義的狀態",
    "Previously set" : "先前設定",
    "Reset status" : "重設狀態",
    "Set status" : "設定狀態",
    "Online status" : "線上狀態",
    "Status message" : "狀態訊息",
    "Your status was set automatically" : "您的狀態為自動設定",
    "Clear status message" : "清空狀態訊息",
    "Set status message" : "設定狀態訊息",
    "Reset status to \"{icon} {message}\"" : "重設狀態為「{icon} {message}」",
    "Reset status to \"{message}\"" : "重設狀態為「{message}」",
    "Reset status to \"{icon}\"" : "重設狀態為「{icon}」",
    "There was an error saving the status" : "儲存狀態時發生錯誤",
    "There was an error clearing the status" : "變更狀態時發生錯誤",
    "There was an error reverting the status" : "還原狀態時發生錯誤",
    "Don't clear" : "不要清空",
    "Today" : "今天",
    "This week" : "本週",
    "Online" : "上線",
    "Away" : "外出",
    "Do not disturb" : "請勿打擾",
    "Invisible" : "隱藏",
    "Offline" : "離線",
    "There was an error saving the new status" : "儲存新狀態時發生錯誤",
    "30 minutes" : "30分鐘",
    "1 hour" : "1小時",
    "4 hours" : "4小時",
    "Mute all notifications" : "所有通知靜音",
    "Appear offline" : "顯示為離線",
    "View profile" : "檢視個人檔案",
    "{status}, {timestamp}" : "{status}，{timestamp}"
},
"nplurals=1; plural=0;");

==> php81-nextcloud-30.0.5.tgz: share/nextcloud/apps/user_status/l10n/zh_TW.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "最近的狀態",
    "No recent status changes" : "最近沒有狀態變更",
    "In a meeting" : "會議中",
    "Commuting" : "通勤中",
    "Out sick" : "病假",
    "Vacationing" : "休假中",
    "Out of office" : "不在辦公室",
    "Working remotely" : "遠端工作",
    "In a call" : "通話中",
    "User status" : "使用者狀態",
    "Clear status after" : "多久後清除狀態",
    "Emoji for your status message" : "狀態訊息的表情符號",
    "What is your status?" : "您目前的狀態是什麼呢？",
    "Predefined statuses" : "預先定義的狀態",
    "Previously set" : "先前設定",
    "Reset status" : "重設狀態",
    "Set status" : "設定狀態",
    "Online status" : "線上狀態",
    "Status message" : "狀態訊息",
    "Set absence period" : "設定缺席時間",
    "Set absence period and replacement" : "設定缺席時間與職務代理人",
    "Your status was set automatically" : "您的狀態為自動設定",
    "Clear status message" : "清除狀態訊息",
    "Set status message" : "設定狀態訊息",
    "Reset status to \"{icon} {message}\"" : "重設狀態為「{icon} {message}」",
    "Reset status to \"{message}\"" : "重設狀態為「{message}」",
    "Reset status to \"{icon}\"" : "重設狀態為「{icon}」",
    "There was an error saving the status" : "儲存狀態時發生錯誤",
    "There was an error clearing the status" : "變更狀態時發生錯誤",
    "There was an error reverting the status" : "還原狀態時發生錯誤",
    "Don't clear" : "不要清除",
    "Today" : "今天",
    "This week" : "本週",
    "Online" : "上線",
    "Away" : "離開",
    "Do not disturb" : "請勿打擾",
    "Invisible" : "隱藏",
    "Offline" : "離線",
    "There was an error saving the new status" : "儲存新狀態時發生錯誤",
    "30 minutes" : "30 分鐘",
    "1 hour" : "1 小時",
    "4 hours" : "4 小時",
    "Mute all notifications" : "靜音所有通知",
    "Appear offline" : "顯示為離線"
},
"nplurals=1; plural=0;");
